@@ -2001,7 +2001,8 @@ public class JsonLdApi {
 
                     // 3.5.4)
                     if (RDF_TYPE.equals(predicate) && (object.isIRI() || object.isBlankNode())
-                            && !opts.getUseRdfType() && !nodes.containsKey(object.getValue())) {
+                            && !opts.getUseRdfType() &&
+                            (!nodes.containsKey(object.getValue()) || subject.equals(object.getValue()))) {
                         JsonLdUtils.mergeValue(node, JsonLdConsts.TYPE, object.getValue());
                         continue;
                     }
